{% extends "admin/base_site.html" %}
{% load i18n static %}

{% block content %}
<div id="content-main">
    <form method="post" id="login-form">
        {% csrf_token %}
        <div class="form-row">
            <label for="id_username">{{ form.username.label }}:</label>
            {{ form.username }}
        </div>
        {% if form.errors %}
            <p class="errornote">
                {% for error in form.non_field_errors %}
                    {{ error }}
                {% endfor %}
            </p>
        {% endif %}
        <div class="submit-row">
            <input type="submit" value="Войти">
        </div>
    </form>
</div>
{% endblock %}